@@ -289,6 +289,30 @@ RppStatus hip_exec_color_temperature_tensor(T *srcPtr,
                                             RpptRoiType roiType,
                                             rpp::Handle& handle);
 
+// -------------------- hue --------------------
+
+template <typename T>
+RppStatus hip_exec_hue_tensor(T *srcPtr,
+                              RpptDescPtr srcDescPtr,
+                              T *dstPtr,
+                              RpptDescPtr dstDescPtr,
+                              Rpp32f *hueTensor,
+                              RpptROIPtr roiTensorPtrSrc,
+                              RpptRoiType roiType,
+                              rpp::Handle& handle);
+                                     
+// -------------------- saturation --------------------
+
+template <typename T>
+RppStatus hip_exec_saturation_tensor(T *srcPtr,
+                                     RpptDescPtr srcDescPtr,
+                                     T *dstPtr,
+                                     RpptDescPtr dstDescPtr,
+                                     Rpp32f *saturationTensor,
+                                     RpptROIPtr roiTensorPtrSrc,
+                                     RpptRoiType roiType,
+                                     rpp::Handle& handle);                                     
+
 // -------------------- color_twist --------------------
 
 template <typename T>
@@ -572,6 +596,30 @@ RppStatus hip_exec_water_tensor(T *srcPtr,
                                 RpptRoiType roiType,
                                 rpp::Handle& handle);
 
+// -------------------- posterize --------------------
+
+template <typename T>
+RppStatus hip_exec_posterize_tensor(T *srcPtr,
+                                    RpptDescPtr srcDescPtr,
+                                    T *dstPtr,
+                                    RpptDescPtr dstDescPtr,
+                                    Rpp8u *posterizeLevelBits,
+                                    RpptROIPtr roiTensorPtrSrc,
+                                    RpptRoiType roiType,
+                                    rpp::Handle& handle);
+
+// -------------------- solarize --------------------
+
+template <typename T>
+RppStatus hip_exec_solarize_tensor(T *srcPtr,
+                                   RpptDescPtr srcDescPtr,
+                                   T *dstPtr,
+                                   RpptDescPtr dstDescPtr,
+                                   Rpp32f *thresholdTensor,
+                                   RpptROIPtr roiTensorPtrSrc,
+                                   RpptRoiType roiType,
+                                   rpp::Handle& handle);
+
 /**************************************** FILTER AUGMENTATIONS ****************************************/
 
 // -------------------- box_filter --------------------
@@ -598,6 +646,18 @@ RppStatus hip_exec_gaussian_filter_tensor(T *srcPtr,
                                           RpptRoiType roiType,
                                           rpp::Handle& handle);
 
+// -------------------- median_filter --------------------
+
+template <typename T>
+RppStatus hip_exec_median_filter_tensor(T *srcPtr,
+                                        RpptDescPtr srcDescPtr,
+                                        T *dstPtr,
+                                        RpptDescPtr dstDescPtr,
+                                        Rpp32u kernelSize,
+                                        RpptROIPtr roiTensorPtrSrc,
+                                        RpptRoiType roiType,
+                                        rpp::Handle& handle);
+
 /**************************************** GEOMETRIC AUGMENTATIONS ****************************************/
 
 // -------------------- crop --------------------
