@@ -612,13 +612,8 @@ RppStatus tensor_max_f16_f16_host(Rpp16f *srcPtr,
 #if __AVX2__
                 for (; vectorLoopCount < alignedLength; vectorLoopCount += vectorIncrement)
                 {
-                    Rpp32f srcPtrTemp_ps[8];
-                    for(int cnt = 0; cnt < vectorIncrement; cnt++)
-                    {
-                        srcPtrTemp_ps[cnt] = (Rpp32f) srcPtrTemp[cnt];
-                    }
                     __m256 p1;
-                    rpp_simd_load(rpp_load8_f32_to_f32_avx, srcPtrTemp_ps, &p1);
+                    rpp_simd_load(rpp_load8_f16_to_f32_avx, srcPtrTemp, &p1);
                     compute_max_float8_host(&p1, &pMax);
 
                     srcPtrTemp += vectorIncrement;
@@ -666,15 +661,8 @@ RppStatus tensor_max_f16_f16_host(Rpp16f *srcPtr,
 #if __AVX2__
                 for (; vectorLoopCount < alignedLength; vectorLoopCount += vectorIncrementPerChannel)
                 {
-                    Rpp32f srcPtrTempR_ps[8], srcPtrTempG_ps[8], srcPtrTempB_ps[8];
-                    for(int cnt = 0; cnt < vectorIncrementPerChannel; cnt++)
-                    {
-                        srcPtrTempR_ps[cnt] = (Rpp32f) srcPtrTempR[cnt];
-                        srcPtrTempG_ps[cnt] = (Rpp32f) srcPtrTempG[cnt];
-                        srcPtrTempB_ps[cnt] = (Rpp32f) srcPtrTempB[cnt];
-                    }
                     __m256 p[3];
-                    rpp_simd_load(rpp_load24_f32pln3_to_f32pln3_avx, srcPtrTempR_ps, srcPtrTempG_ps, srcPtrTempB_ps, p);
+                    rpp_simd_load(rpp_load24_f16pln3_to_f32pln3_avx, srcPtrTempR, srcPtrTempG, srcPtrTempB, p);
                     compute_max_float24_host(p, &pMaxR, &pMaxG, &pMaxB);
 
                     srcPtrTempR += vectorIncrementPerChannel;
@@ -737,13 +725,8 @@ RppStatus tensor_max_f16_f16_host(Rpp16f *srcPtr,
 #if __AVX2__
                     for (; vectorLoopCount < alignedLength; vectorLoopCount += vectorIncrement)
                     {
-                        Rpp32f srcPtrTemp_ps[24];
-                        for(int cnt = 0; cnt < vectorIncrement; cnt++)
-                        {
-                            srcPtrTemp_ps[cnt] = (Rpp32f) srcPtrTemp[cnt];
-                        }
                         __m256 p[3];
-                        rpp_simd_load(rpp_load24_f32pkd3_to_f32pln3_avx, srcPtrTemp_ps, p);
+                        rpp_simd_load(rpp_load24_f16pkd3_to_f32pln3_avx, srcPtrTemp, p);
                         compute_max_float24_host(p, &pMaxR, &pMaxG, &pMaxB);
 
                         srcPtrTemp += vectorIncrement;
