@@ -489,8 +489,8 @@ __global__ void compute_mean_3d_hip_tensor(T *srcPtr,
 
         uint srcIdx = (id_z * srcStridesNZY.x) + ((id_y + zBegin) * srcStridesNZY.y) + ((id_x + yBegin) * srcStridesNZY.z) + xBegin;
         d_float8 accum_f8;
-        accum_f8.f4[0] = (float4)0.0f;
-        accum_f8.f4[1] = (float4)0.0f;
+        accum_f8.f4[0] = FLOAT4_ZERO;
+        accum_f8.f4[1] = FLOAT4_ZERO;
         for(int i = 0; i < lengthX; i += 8)
         {
             d_float8 src_f8;
@@ -569,8 +569,8 @@ __global__ void compute_mean_3d_hip_tensor(T *srcPtr,
         uint maxLengthZ = srcStridesNZY.x / srcStridesNZY.y;
         uint srcIdx = (id_z * srcStridesNZY.x) + ((id_y + zBegin) * srcStridesNZY.y) + ((id_x + yBegin) * srcStridesNZY.z) + xBegin;
         d_float8 accum_f8;
-        accum_f8.f4[0] = (float4)0.0f;
-        accum_f8.f4[1] = (float4)0.0f;
+        accum_f8.f4[0] = FLOAT4_ZERO;
+        accum_f8.f4[1] = FLOAT4_ZERO;
         for(int i = 0; i < lengthX; i += 8)
         {
             d_float8 src_f8;
@@ -821,7 +821,7 @@ __global__ void compute_stddev_2d_hip_tensor(T *srcPtr,
 
         uint paramIndex = id_z * maxParamVolume + id_y;
         float mean = meanTensor[paramIndex];
-        float4 mean_f4 = static_cast<float4>(mean);
+        float4 mean_f4 = MAKE_FLOAT4(mean);
 
         d_float8 src_f8;
         rpp_hip_load8_and_unpack_to_float8(srcPtr + srcIdx, &src_f8);           // load 8 pixels to local memory
@@ -868,7 +868,7 @@ __global__ void compute_stddev_2d_hip_tensor(T *srcPtr,
         uint srcIdx = (id_z * srcStridesNH.x) + ((id_y + yBegin) * srcStridesNH.y) + (id_x + xBegin);
 
         float mean = meanTensor[id_z];
-        float4 mean_f4 = static_cast<float4>(mean);
+        float4 mean_f4 = MAKE_FLOAT4(mean);
 
         d_float8 src_f8;
         rpp_hip_load8_and_unpack_to_float8(srcPtr + srcIdx, &src_f8);           // load 8 pixels to local memory
@@ -973,10 +973,10 @@ __global__ void compute_stddev_3d_hip_tensor(T *srcPtr,
         uint srcIdx = (id_z * srcStridesNZY.x) + ((id_y + zBegin) * srcStridesNZY.y) + ((id_x + yBegin) * srcStridesNZY.z) + xBegin;
         uint paramIndex = id_z * maxParamVolume + id_y * lengthY + id_x;
         float mean = meanTensor[paramIndex];
-        float4 mean_f4 = static_cast<float4>(mean);
+        float4 mean_f4 = MAKE_FLOAT4(mean);
         d_float8 accum_f8;
-        accum_f8.f4[0] = (float4)0.0f;
-        accum_f8.f4[1] = (float4)0.0f;
+        accum_f8.f4[0] = FLOAT4_ZERO;
+        accum_f8.f4[1] = FLOAT4_ZERO;
         for(int i = 0; i < lengthX; i += 8)
         {
             d_float8 src_f8;
@@ -1062,11 +1062,11 @@ __global__ void compute_stddev_3d_hip_tensor(T *srcPtr,
 
         uint paramIndex = id_z * maxParamVolume + id_y;
         float mean = meanTensor[paramIndex];
-        float4 mean_f4 = static_cast<float4>(mean);
+        float4 mean_f4 = MAKE_FLOAT4(mean);
 
         d_float8 accum_f8;
-        accum_f8.f4[0] = (float4)0.0f;
-        accum_f8.f4[1] = (float4)0.0f;
+        accum_f8.f4[0] = FLOAT4_ZERO;
+        accum_f8.f4[1] = FLOAT4_ZERO;
         for(int i = 0; i < lengthX; i += 8)
         {
             d_float8 src_f8;
@@ -1150,7 +1150,7 @@ __global__ void compute_stddev_3d_hip_tensor(T *srcPtr,
 
         uint paramIndex = id_z * maxParamVolume;
         float mean = meanTensor[paramIndex];
-        float4 mean_f4 = static_cast<float4>(mean);
+        float4 mean_f4 = MAKE_FLOAT4(mean);
 
         d_float8 src_f8;
         rpp_hip_load8_and_unpack_to_float8(srcPtr + srcIdx, &src_f8);           // load 8 pixels to local memory
@@ -1407,8 +1407,8 @@ void set_kernel_launch_config_2d(RpptGenericDescPtr srcGenericDescPtr,
             globalThreads_z = srcGenericDescPtr->dims[0];
 
             Rpp32u partialSumArrLength = srcGenericDescPtr->dims[0] * srcGenericDescPtr->dims[1] * globalThreads_x;
-            hipMemsetAsync(partialSumArr, 0, partialSumArrLength * sizeof(Rpp32f), handle.GetStream());
-            hipStreamSynchronize(handle.GetStream());
+            CHECK_RETURN_STATUS(hipMemsetAsync(partialSumArr, 0, partialSumArrLength * sizeof(Rpp32f), handle.GetStream()));
+            CHECK_RETURN_STATUS(hipStreamSynchronize(handle.GetStream()));
             break;
         }
         // compute along XY direction
@@ -1422,8 +1422,8 @@ void set_kernel_launch_config_2d(RpptGenericDescPtr srcGenericDescPtr,
             globalThreads_z = srcGenericDescPtr->dims[0];
 
             Rpp32u partialSumArrLength = globalThreads_x * globalThreads_y * globalThreads_z;
-            hipMemsetAsync(partialSumArr, 0, partialSumArrLength * sizeof(Rpp32f), handle.GetStream());
-            hipStreamSynchronize(handle.GetStream());
+            CHECK_RETURN_STATUS(hipMemsetAsync(partialSumArr, 0, partialSumArrLength * sizeof(Rpp32f), handle.GetStream()));
+            CHECK_RETURN_STATUS(hipStreamSynchronize(handle.GetStream()));
             break;
         }
     }
@@ -1475,8 +1475,8 @@ void set_kernel_launch_config_3d(RpptGenericDescPtr srcGenericDescPtr,
             globalThreads_z = srcGenericDescPtr->dims[0];
 
             Rpp32u partialSumArrLength = globalThreads_x * globalThreads_y * globalThreads_z;
-            hipMemsetAsync(partialSumArr, 0, partialSumArrLength * sizeof(Rpp32f), handle.GetStream());
-            hipStreamSynchronize(handle.GetStream());
+            CHECK_RETURN_STATUS(hipMemsetAsync(partialSumArr, 0, partialSumArrLength * sizeof(Rpp32f), handle.GetStream()));
+            CHECK_RETURN_STATUS(hipStreamSynchronize(handle.GetStream()));
             break;
         }
         // compute along X direction
@@ -1512,8 +1512,8 @@ void set_kernel_launch_config_3d(RpptGenericDescPtr srcGenericDescPtr,
             globalThreads_z = srcGenericDescPtr->dims[0];
 
             Rpp32u partialSumArrLength = globalThreads_x * globalThreads_y * globalThreads_z;
-            hipMemsetAsync(partialSumArr, 0, partialSumArrLength * sizeof(Rpp32f), handle.GetStream());
-            hipStreamSynchronize(handle.GetStream());
+            CHECK_RETURN_STATUS(hipMemsetAsync(partialSumArr, 0, partialSumArrLength * sizeof(Rpp32f), handle.GetStream()));
+            CHECK_RETURN_STATUS(hipStreamSynchronize(handle.GetStream()));
             break;
         }
         // compute along XYZ direction
@@ -1528,8 +1528,8 @@ void set_kernel_launch_config_3d(RpptGenericDescPtr srcGenericDescPtr,
             globalThreads_z = srcGenericDescPtr->dims[0];
 
             Rpp32u partialSumArrLength = globalThreads_x * globalThreads_y * globalThreads_z;
-            hipMemsetAsync(partialSumArr, 0, partialSumArrLength * sizeof(Rpp32f), handle.GetStream());
-            hipStreamSynchronize(handle.GetStream());
+            CHECK_RETURN_STATUS(hipMemsetAsync(partialSumArr, 0, partialSumArrLength * sizeof(Rpp32f), handle.GetStream()));
+            CHECK_RETURN_STATUS(hipStreamSynchronize(handle.GetStream()));
             break;
         }
     }
@@ -1807,7 +1807,7 @@ RppStatus hip_exec_compute_mean_stddev_tensor(T *srcPtr,
                            maxParamVolume,
                            isMean);
     }
-    hipStreamSynchronize(handle.GetStream());
+    CHECK_RETURN_STATUS(hipStreamSynchronize(handle.GetStream()));
     return RPP_SUCCESS;
 }
 
