@@ -347,7 +347,7 @@ RppStatus hip_exec_tensor_max(T *srcPtr,
         Rpp32u partialMaxArrLength = gridDim_x * gridDim_y * gridDim_z;
         float *partialMaxArr;
         partialMaxArr = handle.GetInitHandle()->mem.mgpu.scratchBufferHip.floatmem;
-        hipMemsetAsync(partialMaxArr, minimum, partialMaxArrLength * sizeof(float), handle.GetStream());
+        CHECK_RETURN_STATUS(hipMemsetAsync(partialMaxArr, minimum, partialMaxArrLength * sizeof(float), handle.GetStream()));
         hipLaunchKernelGGL(tensor_max_pln1_hip,
                            dim3(gridDim_x, gridDim_y, gridDim_z),
                            dim3(LOCAL_THREADS_X, LOCAL_THREADS_Y, LOCAL_THREADS_Z),
@@ -357,7 +357,7 @@ RppStatus hip_exec_tensor_max(T *srcPtr,
                            make_uint2(srcDescPtr->strides.nStride, srcDescPtr->strides.hStride),
                            partialMaxArr,
                            roiTensorPtrSrc);
-        hipStreamSynchronize(handle.GetStream());
+        CHECK_RETURN_STATUS(hipStreamSynchronize(handle.GetStream()));
         hipLaunchKernelGGL(tensor_max_grid_result_hip,
                            dim3(1, 1, gridDim_z),
                            dim3(256, 1, 1),
@@ -372,7 +372,7 @@ RppStatus hip_exec_tensor_max(T *srcPtr,
         Rpp32u partialMaxArrLength = gridDim_x * gridDim_y * gridDim_z * 3;
         float *partialMaxArr;
         partialMaxArr = handle.GetInitHandle()->mem.mgpu.scratchBufferHip.floatmem;
-        hipMemsetAsync(partialMaxArr, minimum, partialMaxArrLength * sizeof(float), handle.GetStream());
+        CHECK_RETURN_STATUS(hipMemsetAsync(partialMaxArr, minimum, partialMaxArrLength * sizeof(float), handle.GetStream()));
         hipLaunchKernelGGL(tensor_max_pln3_hip,
                            dim3(gridDim_x, gridDim_y, gridDim_z),
                            dim3(LOCAL_THREADS_X, LOCAL_THREADS_Y, LOCAL_THREADS_Z),
@@ -382,7 +382,7 @@ RppStatus hip_exec_tensor_max(T *srcPtr,
                            make_uint3(srcDescPtr->strides.nStride, srcDescPtr->strides.cStride, srcDescPtr->strides.hStride),
                            partialMaxArr,
                            roiTensorPtrSrc);
-        hipStreamSynchronize(handle.GetStream());
+        CHECK_RETURN_STATUS(hipStreamSynchronize(handle.GetStream()));
         hipLaunchKernelGGL(tensor_max_grid_3channel_result_hip,
                            dim3(1, 1, gridDim_z),
                            dim3(256, 1, 1),
@@ -397,7 +397,7 @@ RppStatus hip_exec_tensor_max(T *srcPtr,
         Rpp32u partialMaxArrLength = gridDim_x * gridDim_y * gridDim_z * 3;
         float *partialMaxArr;
         partialMaxArr = handle.GetInitHandle()->mem.mgpu.scratchBufferHip.floatmem;
-        hipMemsetAsync(partialMaxArr, minimum, partialMaxArrLength * sizeof(float), handle.GetStream());
+        CHECK_RETURN_STATUS(hipMemsetAsync(partialMaxArr, minimum, partialMaxArrLength * sizeof(float), handle.GetStream()));
         hipLaunchKernelGGL(tensor_max_pkd3_hip,
                            dim3(gridDim_x, gridDim_y, gridDim_z),
                            dim3(LOCAL_THREADS_X, LOCAL_THREADS_Y, LOCAL_THREADS_Z),
@@ -407,7 +407,7 @@ RppStatus hip_exec_tensor_max(T *srcPtr,
                            make_uint2(srcDescPtr->strides.nStride, srcDescPtr->strides.hStride),
                            partialMaxArr,
                            roiTensorPtrSrc);
-        hipStreamSynchronize(handle.GetStream());
+        CHECK_RETURN_STATUS(hipStreamSynchronize(handle.GetStream()));
         hipLaunchKernelGGL(tensor_max_grid_3channel_result_hip,
                            dim3(1, 1, gridDim_z),
                            dim3(256, 1, 1),
