@@ -1,7 +1,7 @@
 /*
 MIT License
 
-Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.
+Copyright (c) 2019 - 2025 Advanced Micro Devices, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -601,7 +601,8 @@ int main(int argc, char **argv)
     // Set the number of threads to be used by OpenMP pragma for RPP batch processing on host.
     // If numThreads value passed is 0, number of OpenMP threads used by RPP will be set to batch size
     Rpp32u numThreads = 0;
-    rppCreateWithBatchSize(&handle, noOfImages, numThreads);
+    RppBackend backend = RppBackend::RPP_HOST_BACKEND;
+    rppCreate(&handle, noOfImages, numThreads, nullptr, backend);
 
     double max_time_used = 0, min_time_used = 500, avg_time_used = 0;
 
@@ -1933,7 +1934,7 @@ int main(int argc, char **argv)
 
     cout << fixed << "\nmax,min,avg = " << max_time_used << "," << min_time_used << "," << avg_time_used << endl;
 
-    rppDestroyHost(handle);
+    rppDestroy(handle, backend);
 
     // Free memory
 
