@@ -1,7 +1,7 @@
 /*
 MIT License
 
-Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.
+Copyright (c) 2019 - 2025 Advanced Micro Devices, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -700,7 +700,8 @@ int main(int argc, char **argv)
     rppHandle_t handle;
     hipStream_t stream;
     hipStreamCreate(&stream);
-    rppCreateWithStreamAndBatchSize(&handle, stream, noOfImages);
+    RppBackend backend = RppBackend::RPP_HIP_BACKEND;
+    rppCreate(&handle, noOfImages, 0, stream, backend);
 
     clock_t start, end;
     double gpu_time_used;
@@ -2332,7 +2333,7 @@ int main(int argc, char **argv)
         free(outputCopy);
     }
 
-    rppDestroyGPU(handle);
+    rppDestroy(handle, backend);
 
     // OpenCV dump
 
